Title: [106643] trunk/Source/WebCore
Revision
106643
Author
[email protected]
Date
2012-02-03 02:31:41 -0800 (Fri, 03 Feb 2012)

Log Message

Add the "CPP" prefix to CPP specific IDL attributes
https://bugs.webkit.org/show_bug.cgi?id=77707

Reviewed by Adam Barth.

This patch adds the "CPP" prefix to a CPP specific IDL attribute.
Specifically, this patch renames [PureInterface] to [CPPPureInterface]

No tests. No change in behavior.

* bindings/scripts/CodeGeneratorCPP.pm:
(GenerateHeader):
(GenerateImplementation):
* css/MediaQueryListListener.idl:
* dom/EventListener.idl:
* dom/EventTarget.idl:
* dom/NodeFilter.idl:

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (106642 => 106643)


--- trunk/Source/WebCore/ChangeLog	2012-02-03 10:10:54 UTC (rev 106642)
+++ trunk/Source/WebCore/ChangeLog	2012-02-03 10:31:41 UTC (rev 106643)
@@ -1,3 +1,23 @@
+2012-02-03  Kentaro Hara  <[email protected]>
+
+        Add the "CPP" prefix to CPP specific IDL attributes
+        https://bugs.webkit.org/show_bug.cgi?id=77707
+
+        Reviewed by Adam Barth.
+
+        This patch adds the "CPP" prefix to a CPP specific IDL attribute.
+        Specifically, this patch renames [PureInterface] to [CPPPureInterface]
+
+        No tests. No change in behavior.
+
+        * bindings/scripts/CodeGeneratorCPP.pm:
+        (GenerateHeader):
+        (GenerateImplementation):
+        * css/MediaQueryListListener.idl:
+        * dom/EventListener.idl:
+        * dom/EventTarget.idl:
+        * dom/NodeFilter.idl:
+
 2012-01-27  Alexander Pavlov  <[email protected]>
 
         Implement touch event emulation in the WebCore layer

Modified: trunk/Source/WebCore/bindings/scripts/CodeGeneratorCPP.pm (106642 => 106643)


--- trunk/Source/WebCore/css/MediaQueryListListener.idl	2012-02-03 10:10:54 UTC (rev 106642)
+++ trunk/Source/WebCore/css/MediaQueryListListener.idl	2012-02-03 10:31:41 UTC (rev 106643)
@@ -21,7 +21,7 @@
     interface [
         NoStaticTables,
         ObjCProtocol,
-        PureInterface,
+        CPPPureInterface,
         OmitConstructor
     ] MediaQueryListListener {
         void queryChanged(in [Optional=CallWithDefaultValue] MediaQueryList list);

Modified: trunk/Source/WebCore/dom/EventListener.idl (106642 => 106643)


--- trunk/Source/WebCore/dom/EventListener.idl	2012-02-03 10:10:54 UTC (rev 106642)
+++ trunk/Source/WebCore/dom/EventListener.idl	2012-02-03 10:31:41 UTC (rev 106643)
@@ -24,7 +24,7 @@
     interface [
         NoStaticTables,
         ObjCProtocol,
-        PureInterface,
+        CPPPureInterface,
         OmitConstructor
     ] EventListener {
         void               handleEvent(in Event evt);

Modified: trunk/Source/WebCore/dom/EventTarget.idl (106642 => 106643)


--- trunk/Source/WebCore/dom/EventTarget.idl	2012-02-03 10:10:54 UTC (rev 106642)
+++ trunk/Source/WebCore/dom/EventTarget.idl	2012-02-03 10:31:41 UTC (rev 106643)
@@ -23,7 +23,7 @@
     // Introduced in DOM Level 2:
     interface [
         ObjCProtocol,
-        PureInterface,
+        CPPPureInterface,
         OmitConstructor
     ] EventTarget {
         [OldStyleObjC] void addEventListener(in DOMString type, 

Modified: trunk/Source/WebCore/dom/NodeFilter.idl (106642 => 106643)


--- trunk/Source/WebCore/dom/NodeFilter.idl	2012-02-03 10:10:54 UTC (rev 106642)
+++ trunk/Source/WebCore/dom/NodeFilter.idl	2012-02-03 10:31:41 UTC (rev 106643)
@@ -25,7 +25,7 @@
         CustomMarkFunction,
         CustomNativeConverter,
         ObjCProtocol,
-        PureInterface
+        CPPPureInterface
     ] NodeFilter {
         // Constants returned by acceptNode
         const short               FILTER_ACCEPT                  = 1;
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to
--- trunk/Source/WebCore/bindings/scripts/CodeGeneratorCPP.pm	2012-02-03 10:10:54 UTC (rev 106642)
+++ trunk/Source/WebCore/bindings/scripts/CodeGeneratorCPP.pm	2012-02-03 10:31:41 UTC (rev 106643)
@@ -481,7 +481,7 @@
                 $parameterIndex++;
             }
             $functionSig .= ")";
-            if ($dataNode->extendedAttributes->{"PureInterface"}) {
+            if ($dataNode->extendedAttributes->{"CPPPureInterface"}) {
                 push(@interfaceFunctions, "    virtual " . $functionSig . " = 0;\n");
             }
             my $functionDeclaration = $functionSig;
@@ -513,9 +513,9 @@
 
     push(@headerContent, "};\n\n");
 
     # for PureInterface classes also add the interface that the client code needs to
     # implement
-    if ($dataNode->extendedAttributes->{"PureInterface"}) {
+    if ($dataNode->extendedAttributes->{"CPPPureInterface"}) {
         push(@headerContent, "class WebUser$interfaceName {\n");
         push(@headerContent, "public:\n");
         push(@headerContent, "    virtual void ref() = 0;\n");
@@ -529,7 +529,7 @@
     my $namespace = GetNamespaceForClass($implClassName);
     push(@headerContent, "$namespace" . "::$implClassName* toWebCore(const $className&);\n");
     push(@headerContent, "$className toWebKit($namespace" . "::$implClassName*);\n");
-    if ($dataNode->extendedAttributes->{"PureInterface"}) {
+    if ($dataNode->extendedAttributes->{"CPPPureInterface"}) {
         push(@headerContent, "$className toWebKit(WebUser$interfaceName*);\n");
     }
     push(@headerContent, "\n#endif\n");
@@ -783,8 +783,8 @@
     # - Functions
     if ($numFunctions > 0) {
         foreach my $function (@{$dataNode->functions}) {
-            # Treat PureInterface as Custom as well, since the WebCore versions will take a script context as well
-            next if ShouldSkipType($function) || $dataNode->extendedAttributes->{"PureInterface"};
+            # Treat CPPPureInterface as Custom as well, since the WebCore versions will take a script context as well
+            next if ShouldSkipType($function) || $dataNode->extendedAttributes->{"CPPPureInterface"};
             AddIncludesForType($function->signature->type);
 
             my $functionName = $function->signature->name;
@@ -513,9 +513,9 @@
     push(@headerContent, "};\n\n");
 
-    # for PureInterface classes also add the interface that the client code needs to
+    # for CPPPureInterface classes also add the interface that the client code needs to
     # implement

Modified: trunk/Source/WebCore/css/MediaQueryListListener.idl (106642 => 106643)

